# Torproject

Aktuell stelle ich nur ein Installationsscript für Ubuntu zu Verfügung.
Man kann Tor Relay selbstverständlich auch aus den Paketquellen von Ubuntu installieren, jedoch sind die Pakete oft nicht aktuell und deshalb sicherheitstechnisch schwierig.


## Voraussetzungen:

OS: `Ubuntu 22.04`

Architektur: `amd64`

## Installation

Die Installation kann einfach gestartet werden:

`curl -s https://git.media-techport.de/scriptos/torproject/raw/branch/main/tor-relay-installer-ubuntu2204.v1.sh | bash`


## Konfiguration

Die Konfiguration wird üblicherweise nach der Installation mit `nano /etc/tor/torrc` vorgenommen.

| Option                         | Beschreibung                                                       | Beispiel / Standardwert |
| ------------------------------ | ------------------------------------------------------------------ | ----------------------- |
| `SocksPort`                    | Gibt den Port an, auf dem Tor SOCKS-Anfragen entgegennimmt.         | `9050` |
| `Log`                          | Legt fest, wo und in welchem Format Tor Protokolleinträge speichert.| `notice file /var/log/tor/notices.log` |
| `ExitPolicy`                   | Bestimmt, welche Art von Ausgangsverkehr vom Server erlaubt wird.   | `reject *:*` |
| `HiddenServiceDir`             | Verzeichnis, in dem Informationen zu versteckten Diensten gespeichert werden. | `/var/lib/tor/hidden_service/` |
| `HiddenServicePort`            | Gibt die Portnummer an, die für einen versteckten Dienst verwendet wird. | `80 127.0.0.1:8080` |
| `ControlPort`                  | Port für die Tor-Steuerungsschnittstelle.                          | `9051` |
| `HashedControlPassword`        | Passwort für die Authentifizierung an der Steuerungsschnittstelle. | `16:872860B760133C1D60E856594C8C704751AF76C584B510D` |
| `DataDirectory`                | Speicherort für Tor-Laufzeitdaten.                                 | `/var/lib/tor` |
| `GeoIPFile`                    | Pfad zur GeoIP-Datenbankdatei für die Standorterkennung.           | `/usr/share/tor/geoip` |
| `HardwareAccel`                | Aktiviert Hardware-Beschleunigung, falls verfügbar.                | `1` |
| `ClientOnly`                   | Definiert, ob der Knoten nur als Client und nicht als Relay fungieren soll. | `1` |
| `RelayBandwidthRate`           | Begrenzt die Bandbreite, die das Tor-Relay verwendet.              | `100 KBytes` |
| `RelayBandwidthBurst`          | Erlaubt kurzfristige Überschreitung der Bandbreitenbeschränkung.   | `200 KBytes` |
| `ExcludeExitNodes`             | Verhindert, dass bestimmte Knoten als Exit-Relays verwendet werden.| `{ru},{ua},{by}` |
| `NumEntryGuards`               | Anzahl der Eintrittswächter, die Tor für Pfade verwendet.          | `3` |
| `CircuitBuildTimeout`          | Zeitlimit für den Aufbau eines Tor-Circuits.                       | `60` |
| `KeepalivePeriod`              | Zeitintervall für das Senden von Keep-Alive-Nachrichten.           | `60` |
| `NewCircuitPeriod`             | Zeitraum, nach dem Tor automatisch neue Circuits erstellt.         | `10` |
| `DisableNetwork`               | Schaltet die Netzwerkfunktion von Tor temporär aus.                | `0` |
| `UseBridges`                   | Gibt an, ob Tor Bridges anstelle von normalen Entry-Nodes verwenden soll. | `1` |
| `MyFamily`                     | Liste von Fingerabdrücken anderer Relays, die vom selben Betreiber verwaltet werden. | `MyFamily $keyid1,$keyid2,...` |

Weitere Informationen stehen in der Konfigurationsdatei (auf Englisch)

## Tor Relay starten

Das Relay kann nach der Konfiguration mit `systemctl start tor.service` gestartet werden.


## Nyx in Verbindung mit Tor

Nyx, früher bekannt als Arm (Anonymizing Relay Monitor), ist eine Befehlszeilenanwendung für die Überwachung und Steuerung von Tor-Knoten. Sie bietet:

- Bietet detaillierte Echtzeit-Statistiken über den Betrieb eines Tor-Knotens.
- Einschließlich Bandbreitennutzung, Verbindungen, Logs und mehr.
- Ermöglicht das Überprüfen und Anpassen der Tor-Konfiguration direkt über die Anwendung.
- Zeigt eine Übersicht über den aktuellen Zustand des Tor-Netzwerks.
- Einsicht in Verbindungen, die durch den eigenen Knoten gehen.
- Anzeige von Tor-Logdateien in Echtzeit, nützlich für Fehlersuche und Monitoring.
- Trotz der Befehlszeilenbasis, bietet es eine benutzerfreundliche Schnittstelle.
- Ermöglicht auch weniger technisch versierten Benutzern effektive Überwachung und Verwaltung ihrer Tor-Instanzen.

Nyx ist ein essenzielles Werkzeug für jeden, der einen Tor-Knoten betreibt, insbesondere für diejenigen, die eine detaillierte Übersicht und Kontrolle über ihre Tor-Instanzen benötigen.

Nyx wir ganz einfach gestartet mit `nyx`


## UFW Firewall

UFW kann folgendermaßen konfiguriert werden:

`sudo ufw allow from any to any port 9001 proto tcp comment "ANY > TOR Onion Routing"`

`sudo ufw allow from any to any port 9030 proto tcp comment "ANY > TOR Directory Port"`

`ufw reload`


## Weiterführende Links

- https://nyx.torproject.org/#config_editor
- https://deb.torproject.org/
- https://community.torproject.org/de/onion-services/setup/install/#installing-tor-from-source
- https://support.torproject.org/de/relay-operators/
- https://support.torproject.org/de/apt/tor-deb-repo/
